<?php
/**
 * Plugin Name: First response
 * Plugin URI: http://jess-mann.com
 * Description: Adds a "911 calls" post type for listing the calls your department is dispatched for
 * Version: 1.1
 * Author: Jess Mann
 * Author URI: http://jess-mann.com
 * License: GPLv2 or later
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

// Register Custom Post Type
function ems_post_type() 
{
	$labels = array(
		'name'                => _x( '911 Calls', 'Post Type General Name', 'first-response' ),
		'singular_name'       => _x( '911 Call', 'Post Type Singular Name', 'first-response' ),
		'menu_name'           => __( '911 Calls', 'first-response' ),
		'parent_item_colon'   => __( 'Parent Call:', 'first-response' ),
		'all_items'           => __( 'All Calls', 'first-response' ),
		'view_item'           => __( 'View Call', 'first-response' ),
		'add_new_item'        => __( 'Add New Call', 'first-response' ),
		'add_new'             => __( 'Add New', 'first-response' ),
		'edit_item'           => __( 'Edit Call', 'first-response' ),
		'update_item'         => __( 'Update Call', 'first-response' ),
		'search_items'        => __( 'Search for Calls', 'first-response' ),
		'not_found'           => __( 'Not found', 'first-response' ),
		'not_found_in_trash'  => __( 'Not found in Trash', 'first-response' ),
	);
	$rewrite = array(
		'slug'                => 'call',
		'with_front'          => true,
		'pages'               => true,
		'feeds'               => true,
	);
	$args = array(
		'label'               => __( 'ems_call', 'first-response' ),
		'description'         => __( '911 calls for our department', 'first-response' ),
		'labels'              => $labels,
		'supports'            => array( 'title', 'editor', 'excerpt', 'revisions', ),
		'taxonomies'	      => array( 'category', 'post_tag' ),
		'hierarchical'        => false,
		'public'              => true,
		'show_ui'             => true,
		'show_in_menu'        => true,
		'show_in_nav_menus'   => true,
		'show_in_admin_bar'   => true,
		'menu_position'       => 5,
		'menu_icon'           => 'dashicons-phone',
		'can_export'          => true,
		'has_archive'         => true,
		'exclude_from_search' => false,
		'publicly_queryable'  => true,
		'rewrite'             => $rewrite,
		'capability_type'     => 'post',
	);
	register_post_type( 'ems_call', $args );
}

// Hook into the 'init' action
add_action( 'init', 'ems_post_type', 0 );

function ems_load_calls_page()
{	
	require_once 'Emergency_Call.php';
	?>

	<div class="wrap">
		<div id="icon-tools" class="icon32"></div>
		<h2>Load New Calls from I Am Responding</h2>

		<?php echo Emergency_Call::find_recent_calls(true); ?>
	</div>

	<?php
}

function ems_load_calls_menu()
{
	add_submenu_page( 'edit.php?post_type=ems_call', 'Load New Calls', 'Load Calls', 'manage_options', 'load-calls', 'ems_load_calls_page' );
}
add_action('admin_menu','ems_load_calls_menu');
